@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_BACKEND_STORAGEFACTORYREGISTRY_H
-#define AKREGATOR_BACKEND_STORAGEFACTORYREGISTRY_H
+#pragma once
 
 #include "akregatorinterfaces_export.h"
 #include <QHash>
@@ -37,12 +36,11 @@ private:
     static StorageFactoryRegistry *m_instance;
 
     StorageFactoryRegistry();
-    StorageFactoryRegistry(const StorageFactoryRegistry &);
-    StorageFactoryRegistry &operator=(const StorageFactoryRegistry &);
+    StorageFactoryRegistry(const StorageFactoryRegistry &) = delete;
+    StorageFactoryRegistry &operator=(const StorageFactoryRegistry &) = delete;
 
     QHash<QString, StorageFactory *> m_map;
 };
 } // namespace Backend
 } // namespace Akregator
 
-#endif // STORAGEFACTORYREGISTRY_H
