@@ -10,12 +10,15 @@
 
 #include "command.h"
 
+#include <memory>
+
 namespace Akregator
 {
 class Folder;
 class MainWidget;
 class SubscriptionListView;
 class TreeNode;
+class CreateFeedCommandPrivate;
 
 class CreateFeedCommand : public Command
 {
@@ -35,8 +38,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class CreateFeedCommandPrivate;
+    std::unique_ptr<CreateFeedCommandPrivate> const d;
 };
 }
 
