@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKRWEBENGINEVIEWER_H
-#define AKRWEBENGINEVIEWER_H
+#pragma once
 
 #include "articleviewer-ng/webengine/articleviewerwebengine.h"
 
@@ -18,6 +17,7 @@ class AkrWebEngineViewer : public ArticleViewerWebEngine
 public:
     explicit AkrWebEngineViewer(KActionCollection *ac, QWidget *parent = nullptr);
     ~AkrWebEngineViewer() override;
+    void updateSecurity() override;
 
 protected:
     void displayContextMenu(const QPoint &pos) override;
@@ -29,4 +29,3 @@ private Q_SLOTS:
 };
 }
 
-#endif // WEBENGINEVIEWER_H
