@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ URLHandlerWebEngineManager::URLHandlerWebEngineManager(QObject *parent)
     registerHandler(new ActionURLHandlerWebEngine());
 }
 
-URLHandlerWebEngineManager::~URLHandlerWebEngineManager()
-{
-}
+URLHandlerWebEngineManager::~URLHandlerWebEngineManager() = default;
 
 URLHandlerWebEngineManager *URLHandlerWebEngineManager::instance()
 {
